% script plot_AWI_antenna_S1P.m
%
% This script takes S1P file measurements of each antenna that are saved by
% the network analyzer (Keysight Fieldfox Micrwave Analyzer N9917A 18 GHz)
% and produces plots to check that the cables/connections/antennas are in
% good shape. Produces the plots in the "Antenna Measurements_v2.pdf"
% manual.
%
% YYYY_MM_DD_ANT1.s1p to YYYY_MM_DD_ANT24.s1p
%
% Choose "Sweep" and set the number of "Points" to 10001 as shown in
% "sweep_settings.jpg".
%
% Choose "Cal" Calibration: 1-port OSL with 85054D calibration kit as shown
% in "calibration_settings.jpg".
%
% After calibration, check that the "Load" produces the same picture as
% "return_loss_load_after_calibration.jpg". The plot should be below about
% -40 dB.
%
% After removing the load and adding the Type-N to TNC adapter, check that
% the "Open" produces the same picture as "return_loss_TNC_adapter.jpg".
% This should be 0 dB except for a small dip at the higher frequencies.
%
% Choose "Save" and set the file storage to "USB". Place a USB drive in the
% network analyzer's USB port.
%
% Choose "Save" and set the "File Type" to "Data (S1P)"
%
% Then save the data using the naming convention:
% YYYY_MM_DD_ANT1.s1p to YYYY_MM_DD_ANT24.s1p
%
% =========================================================================
% Other settings can be left on their default settings:
% Frequency: default settings (full bandwidth, 30 kHz - 18.00 GHz)
% Power: "High" output power
% Average: off (1), smoothing "off"
% Advanced calibration settings.

% Edit the filename to match the above

%% USER SETTINGS
% =========================================================================
fn_name_base = '2022_05_03';
antenna_list = 1:8;
% antenna_list = 9:16;
% antenna_list = 17:24;

%% AUTOMATED
% =========================================================================
legend_str = {};
h_freq_fig = figure(1); clf;
h_freq_zoom_fig = figure(2); clf;
h_freq_VSWR_fig = figure(4); clf;
h_time_fig = figure(3); clf;
h_time_fullBW_fig = figure(6); clf;
h_freq_time_gate_VSWR_fig = figure(5); clf;
for ant = antenna_list
  fn = sprintf('%s_ANT%d.s1p',fn_name_base,ant);
  [freq, data] = SXPParse(fn);
  % Set freq_start and freq_end to match "Antenna Measurements_v2.pdf"
  % manual: 150e6 to 600e6
  freq_start = 150e6;
  freq_end = 600e6;
  freq_mask = freq >= freq_start & freq <= freq_end;
  Nt = sum(freq_mask);
  df = freq(2)-freq(1);
  BW = df*Nt;
  dt = 1/BW;
  time = dt*(0:Nt-1).';
  range = time * 3e8/2 * 0.7; % 0.7 velocity factor for cable dielectric
  legend_str{end+1} = sprintf('Ant %d', ant);
  S11 = squeeze(data(1,1,:)); freq = freq(:);
  figure(h_freq_fig);
  plot(freq/1e9,20*log10(abs(S11)));
  title('Return loss')
  hold on;
  grid on;
  xlim([0 18])
  ylim([-25 5]);
  xlabel('Frequency (GHz)');
  ylabel('Return loss (dB)');
  figure(h_freq_zoom_fig);
  plot(freq/1e6,20*log10(abs(S11)));
  title('Return loss')
  xlim([100 700])
  ylim([-25 5]);
  xlabel('Frequency (MHz)');
  ylabel('Return loss (dB)');
  hold on;
  grid on;

  figure(h_freq_VSWR_fig);
  plot(freq/1e6,(1+abs(S11)) ./ (1-abs(S11)));
  title('VSWR')
  xlim([100 600])
  ylim([1 6]);
  xlabel('Frequency (MHz)');
  ylabel('VSWR');
  hold on;
  grid on;

  figure(h_time_fig);
  S11_time = ifft(S11(freq_mask) .* hanning(Nt));
  plot(range,20*log10(abs(S11_time)));
  title(sprintf('Distance to fault using %g-%g MHz (Fig. 6)', round(min(freq(freq_mask))/1e6), round(max(freq(freq_mask))/1e6) ))
  ylim([-100 5]);
  xlim([0 400e-9]*3e8/2 * 0.7); % Set to match "Antenna Measurements_v2.pdf" manual
  xlabel('Range (m)');
  ylabel('Return loss (dB)');
  hold on;
  grid on;

  freq_mask = freq >= -inf & freq <= inf;
  Nt = sum(freq_mask);
  df = freq(2)-freq(1);
  BW = df*Nt;
  dt = 1/BW;
  time = dt*(0:Nt-1).';
  range = time * 3e8/2 * 0.7; % 0.7 velocity factor for cable dielectric

  figure(h_time_fullBW_fig);
  S11_time = ifft(S11(freq_mask) .* hanning(Nt));
  plot(range,20*log10(abs(S11_time)));
  title(sprintf('Distance to fault using %g-%g MHz', round(min(freq(freq_mask))/1e6), round(max(freq(freq_mask))/1e6) ))
  ylim([-100 5]);
  xlim([0 400e-9]*3e8/2 * 0.7); % Set to match "Antenna Measurements_v2.pdf" manual
  xlabel('Range (m)');
  ylabel('Return loss (dB)');
  hold on;
  grid on;

  S11_td = ifft(S11);
  % Ranges for center fuselage array when the network analyzer
  % open-short-load calibration is done at the antenna cable connectors
  % that connect to the T/R switch box.
  %
  % range_start to range_stop should span the main lobe of the antenna return
  warning('If the range_start and range_stop are not set properly, the time (range) gated response will not be correct.')
  range_start = 13.2;
  range_stop = 15.6;
  range_mid = (range_start+range_stop)/2;
  range_width = range_stop - range_start;
  S11_time_gate = fft(S11_td .* tukeywin_cont((range-range_mid)/range_width,0.1));
  figure(h_freq_time_gate_VSWR_fig);
  plot(freq/1e6,(1+abs(S11_time_gate)) ./ (1-abs(S11_time_gate)));
  title(sprintf('VSWR with time gate: %.f-%.1f m range (Fig. 4)', range_start, range_stop))
  xlim([100 600])
  ylim([1 6]);
  xlabel('Frequency (MHz)');
  ylabel('VSWR');
  hold on;
  grid on;
end
figure(h_freq_fig);
legend(legend_str,'location','best');
figure(h_freq_zoom_fig);
legend(legend_str,'location','best');
figure(h_freq_VSWR_fig);
legend(legend_str,'location','best');
figure(h_time_fig);
legend(legend_str,'location','best');
figure(h_time_fullBW_fig);
legend(legend_str,'location','best');
figure(h_freq_time_gate_VSWR_fig);
legend(legend_str,'location','best');

saveas(h_freq_fig,sprintf('%s_freq.fig',fn_name_base))
saveas(h_freq_fig,sprintf('%s_freq.png',fn_name_base))
saveas(h_freq_zoom_fig,sprintf('%s_freq_zoom.fig',fn_name_base))
saveas(h_freq_zoom_fig,sprintf('%s_freq_zoom.png',fn_name_base))
saveas(h_freq_VSWR_fig,sprintf('%s_freq_VSWR_zoom.fig',fn_name_base))
saveas(h_freq_VSWR_fig,sprintf('%s_freq_VSWR_zoom.png',fn_name_base))
saveas(h_time_fig,sprintf('%s_time.fig',fn_name_base))
saveas(h_time_fig,sprintf('%s_time.png',fn_name_base))
saveas(h_time_fullBW_fig,sprintf('%s_time_fullBW.fig',fn_name_base))
saveas(h_time_fullBW_fig,sprintf('%s_time_fullBW.png',fn_name_base))
saveas(h_freq_time_gate_VSWR_fig,sprintf('%s_freq_VSWR_time_gate_zoom.fig',fn_name_base))
saveas(h_freq_time_gate_VSWR_fig,sprintf('%s_freq_VSWR_time_gate_zoom.png',fn_name_base))
